==> kubernetes-model-metrics-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/ContainerMetricsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ContainerMetricsFluentImpl<A extends io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<A>{
  public ContainerMetricsFluentImpl() {
  }
  public ContainerMetricsFluentImpl(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance) {
    this.withName(instance.getName()); 
    this.withUsage(instance.getUsage()); 
  }
  private java.lang.String name;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToUsage(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.usage == null && key != null && value != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.usage.put(key, value);} return (A)this;
  }
  public A addToUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null && map != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.usage.putAll(map);} return (A)this;
  }
  public A removeFromUsage(java.lang.String key) {
    if(this.usage == null) { return (A) this; }
    if(key != null && this.usage != null) {this.usage.remove(key);} return (A)this;
  }
  public A removeFromUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.usage != null){this.usage.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getUsage() {
    return this.usage;
  }
  public <K,V>A withUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage) {
    if (usage == null) { this.usage =  null;} else {this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(usage);} return (A) this;
  }
  public java.lang.Boolean hasUsage() {
    return this.usage != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerMetricsFluentImpl that = (ContainerMetricsFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (usage != null ? !usage.equals(that.usage) :that.usage != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  usage,  super.hashCode());
  }
  
}

==> kubernetes-model-metrics-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/ContainerMetricsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ContainerMetricsFluentImpl<A extends io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<A>{
  public ContainerMetricsFluentImpl() {
  }
  public ContainerMetricsFluentImpl(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance) {
    this.withName(instance.getName()); 
    this.withUsage(instance.getUsage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToUsage(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.usage == null && key != null && value != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.usage.put(key, value);} return (A)this;
  }
  public A addToUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null && map != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.usage.putAll(map);} return (A)this;
  }
  public A removeFromUsage(java.lang.String key) {
    if(this.usage == null) { return (A) this; }
    if(key != null && this.usage != null) {this.usage.remove(key);} return (A)this;
  }
  public A removeFromUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.usage != null){this.usage.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getUsage() {
    return this.usage;
  }
  public <K,V>A withUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage) {
    if (usage == null) { this.usage =  null;} else {this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(usage);} return (A) this;
  }
  public java.lang.Boolean hasUsage() {
    return this.usage != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerMetricsFluentImpl that = (ContainerMetricsFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (usage != null ? !usage.equals(that.usage) :that.usage != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  usage,  additionalProperties,  super.hashCode());
  }
  
}
